@@ -1,9 +1,8 @@
 package Devel::REPL::Plugin::Nopaste;
 
 use Devel::REPL::Plugin;
-use MooseX::AttributeHelpers;
 use Moose::Util::TypeConstraints;
-use namespace::clean -except => [ 'meta' ];
+use namespace::autoclean;
 use Scalar::Util qw(blessed);
 
 sub BEFORE_PLUGIN {
@@ -17,8 +16,8 @@ has complete_session => (
     isa       => 'Str',
     lazy      => 1,
     default   => '',
-    provides  => {
-        append => 'add_to_session',
+    handles  => {
+        add_to_session => 'append',
     },
 );
 
